@@ -24,8 +24,9 @@ module Elasticsearch
 
           option_method :query
           option_method :operator
-          option_method :type
           option_method :boost
+          option_method :fuzziness
+          option_method :max_expansions
         end
 
       end
